Method: Xcodeproj::Project::Object::PBXBuildRule#output_files_compiler_flags

Defined in:
lib/xcodeproj/project/object/build_rule.rb

#output_files_compiler_flagsObjectList<String>

Returns the compiler flags used when creating the respective output files.

Returns:

  • (ObjectList<String>)

    the compiler flags used when creating the respective output files.



64
# File 'lib/xcodeproj/project/object/build_rule.rb', line 64

attribute :output_files_compiler_flags, Array