Class: Xcodeproj::Project::Object::PBXShellScriptBuildPhase
- Inherits:
-
AbstractBuildPhase
- Object
- AbstractObject
- AbstractBuildPhase
- Xcodeproj::Project::Object::PBXShellScriptBuildPhase
- Defined in:
- lib/xcodeproj/project/object/build_phase.rb
Overview
This phase can appear multiple times in a target.
A phase responsible of running a shell script (aka ‘Run Script`).
Attributes collapse
-
#input_paths ⇒ Array<String>
An array of the paths to pass to the script.
-
#name ⇒ String
The name of the build phase.
-
#output_paths ⇒ Array<String>
An array of output paths of the script.
-
#shell_path ⇒ String
The path to the script interpreter.
-
#shell_script ⇒ String
The actual script to perform.
-
#show_env_vars_in_log ⇒ String
Whether or not the ENV variables should be shown in the build log.
Attributes inherited from AbstractBuildPhase
#build_action_mask, #comments, #run_only_for_deployment_postprocessing
Attributes inherited from AbstractObject
Method Summary
Methods inherited from AbstractBuildPhase
#add_file_reference, #build_file, #clear, #file_display_names, #files, #files_references, #include?, #remove_build_file, #remove_file_reference
Methods inherited from AbstractObject
#<=>, #==, #display_name, #inspect, isa, #pretty_print, #remove_from_project, #sort, #sort_recursively, #to_hash
Instance Attribute Details
#input_paths ⇒ Array<String>
Returns an array of the paths to pass to the script.
243 |
# File 'lib/xcodeproj/project/object/build_phase.rb', line 243 attribute :input_paths, Array, [] |
#name ⇒ String
Returns the name of the build phase.
236 |
# File 'lib/xcodeproj/project/object/build_phase.rb', line 236 attribute :name, String |
#output_paths ⇒ Array<String>
Returns an array of output paths of the script.
250 |
# File 'lib/xcodeproj/project/object/build_phase.rb', line 250 attribute :output_paths, Array, [] |
#shell_path ⇒ String
Defaults to /bin/sh.
Returns the path to the script interpreter.
256 |
# File 'lib/xcodeproj/project/object/build_phase.rb', line 256 attribute :shell_path, String, '/bin/sh' |
#shell_script ⇒ String
Defaults to the empty string.
Returns the actual script to perform.
262 |
# File 'lib/xcodeproj/project/object/build_phase.rb', line 262 attribute :shell_script, String, '' |
#show_env_vars_in_log ⇒ String
Defaults to true (1).
Returns whether or not the ENV variables should be shown in the build log.
269 |
# File 'lib/xcodeproj/project/object/build_phase.rb', line 269 attribute :show_env_vars_in_log, String, '1' |